@@ -18,6 +18,7 @@
 #include <stdexcept>
 #include <memory>
 #include "ImageListSet.h"
+#include "Parameters.h"
 #include "NppDarkMode.h"
 #include "dpiManagerV2.h"
 
@@ -43,7 +44,7 @@ void IconList::create(int iconSize, HINSTANCE hInst, int* iconIDArray, int iconI
 		addIcon(iconIDArray[i], iconSize, iconSize);
 }
 
-void IconList::addIcon(int iconID, int cx, int cy, int failIconID) const
+void IconList::addIcon(int iconID, int cx, int cy, int failIconID, bool isToolbarNormal) const
 {
 	HICON hIcon = nullptr;
 	DPIManagerV2::loadIcon(_hInst, MAKEINTRESOURCE(iconID), cx, cy, &hIcon, LR_DEFAULTSIZE);
@@ -74,13 +75,14 @@ void IconList::addIcon(int iconID, int cx, int cy, int failIconID) const
 					return;
 				}
 			}
-			constexpr int IDI_ICONABSENT = 104; // check resource.h for correct id
 			DPIManagerV2::loadIcon(_hInst, MAKEINTRESOURCE(IDI_ICONABSENT), cx, cy, &hIcon);
 		}
 	}
 
 	if (hIcon != nullptr)
 	{
+		if (isToolbarNormal)
+			IconList::changeFluentIconColor(&hIcon);
 		::ImageList_AddIcon(_hImglst, hIcon);
 		::DestroyIcon(hIcon);
 	}
@@ -92,22 +94,223 @@ void IconList::addIcon(HICON hIcon) const
 		ImageList_AddIcon(_hImglst, hIcon);
 }
 
-bool IconList::changeIcon(size_t index, const wchar_t *iconLocation) const
+bool IconList::changeIcon(size_t index, const wchar_t* iconLocation) const
 {
-	HBITMAP hBmp = (HBITMAP)::LoadImage(_hInst, iconLocation, IMAGE_ICON, _iconSize, _iconSize, LR_LOADFROMFILE | LR_LOADMAP3DCOLORS | LR_LOADTRANSPARENT);
-	if (!hBmp)
+	HICON hIcon = nullptr;
+	DPIManagerV2::loadIcon(nullptr, iconLocation, _iconSize, _iconSize, &hIcon, LR_LOADFROMFILE | LR_LOADMAP3DCOLORS | LR_LOADTRANSPARENT);
+	if (!hIcon)
 		return false;
-	size_t i = ImageList_ReplaceIcon(_hImglst, int(index), (HICON)hBmp);
-	ImageList_AddMasked(_hImglst, (HBITMAP)hBmp, RGB(255,0,255));
-	::DeleteObject(hBmp);
+	size_t i = ::ImageList_ReplaceIcon(_hImglst, static_cast<int>(index), hIcon);
+	::DestroyIcon(hIcon);
 	return (i == index);
 }
 
+
+bool IconList::changeFluentIconColor(HICON* phIcon, const std::vector<std::pair<COLORREF, COLORREF>>& colorMappings, int tolerance) const
+{
+	if (!*phIcon)
+	{
+		return false;
+	}
+
+	HDC hdcScreen = nullptr;
+	HDC hdcBitmap = nullptr;
+	BITMAP bm{};
+	ICONINFO ii{};
+	HBITMAP hbmNew = nullptr;
+	std::unique_ptr<RGBQUAD[]> pixels;
+
+	const bool changeEverything = colorMappings[0].first == 0;
+
+	auto cleanup = [&]()
+		{
+			if (hdcScreen) ::ReleaseDC(nullptr, hdcScreen);
+			if (hdcBitmap) ::DeleteDC(hdcBitmap);
+			if (ii.hbmColor) ::DeleteObject(ii.hbmColor);
+			if (ii.hbmMask) ::DeleteObject(ii.hbmMask);
+			if (hbmNew) ::DeleteObject(hbmNew);
+		};
+
+	hdcScreen = ::GetDC(nullptr);
+	hdcBitmap = ::CreateCompatibleDC(nullptr);
+
+	if (!hdcScreen || !hdcBitmap || !::GetIconInfo(*phIcon, &ii) || !ii.hbmColor || !::GetObject(ii.hbmColor, sizeof(BITMAP), &bm))
+	{
+		cleanup();
+		return false;
+	}
+
+	BITMAPINFO bmi{};
+	bmi.bmiHeader.biSize = sizeof(BITMAPINFOHEADER);
+	bmi.bmiHeader.biWidth = bm.bmWidth;
+	bmi.bmiHeader.biHeight = -bm.bmHeight; // Top-down bitmap
+	bmi.bmiHeader.biPlanes = 1;
+	bmi.bmiHeader.biBitCount = 32;
+	bmi.bmiHeader.biCompression = BI_RGB;
+
+	pixels = std::make_unique<RGBQUAD[]>(static_cast<size_t>(bm.bmWidth) * bm.bmHeight);
+	if (!pixels || !::GetDIBits(hdcBitmap, ii.hbmColor, 0, bm.bmHeight, pixels.get(), &bmi, DIB_RGB_COLORS))
+	{
+		cleanup();
+		return false;
+	}
+
+	for (int i = 0; i < bm.bmWidth * bm.bmHeight; i++)
+	{
+		if (pixels[i].rgbReserved != 0) // Modify non-transparent pixels
+		{
+			if (changeEverything)
+			{
+				COLORREF cNew = colorMappings[0].second == 0 ? NppDarkMode::getAccentColor() : colorMappings[0].second;
+				pixels[i].rgbRed = GetRValue(cNew);
+				pixels[i].rgbGreen = GetGValue(cNew);
+				pixels[i].rgbBlue = GetBValue(cNew);
+			}
+			else
+			{
+				for (const auto& [cToChange, cNew] : colorMappings)
+				{
+
+					if (std::abs(pixels[i].rgbRed - GetRValue(cToChange)) <= tolerance &&
+						std::abs(pixels[i].rgbGreen - GetGValue(cToChange)) <= tolerance &&
+						std::abs(pixels[i].rgbBlue - GetBValue(cToChange)) <= tolerance)
+					{
+						COLORREF finalNewColor = (cNew == 0) ? NppDarkMode::getAccentColor() : cNew;
+						pixels[i].rgbRed = GetRValue(finalNewColor);
+						pixels[i].rgbGreen = GetGValue(finalNewColor);
+						pixels[i].rgbBlue = GetBValue(finalNewColor);
+						break;
+					}
+				}
+			}
+		}
+	}
+
+	hbmNew = ::CreateCompatibleBitmap(hdcScreen, bm.bmWidth, bm.bmHeight);
+	if (!hbmNew || !::SetDIBits(hdcBitmap, hbmNew, 0, bm.bmHeight, pixels.get(), &bmi, DIB_RGB_COLORS))
+	{
+		cleanup();
+		return false;
+	}
+
+	if (ii.hbmColor)
+	{
+		::DeleteObject(ii.hbmColor);
+		ii.hbmColor = nullptr;
+	}
+
+	ii.hbmColor = hbmNew;
+	HICON hIconNew = ::CreateIconIndirect(&ii);
+	if (!hIconNew)
+	{
+		cleanup();
+		return false;
+	}
+
+	::DestroyIcon(*phIcon);
+	*phIcon = hIconNew;
+
+	cleanup();
+	return true;
+}
+
+bool IconList::changeFluentIconColor(HICON* phIcon) const
+{
+	const auto cMain = NppDarkMode::isEnabled() ? g_cDefaultMainDark : g_cDefaultMainLight;
+	const auto cSecondary = NppDarkMode::isEnabled() ? g_cDefaultSecondaryDark : g_cDefaultSecondaryLight;
+	std::vector<std::pair<COLORREF, COLORREF>> colorMappings;
+
+	NppParameters& nppParams = NppParameters::getInstance();
+	const auto& tbInfo = nppParams.getNppGUI()._tbIconInfo;
+
+	COLORREF cOld = tbInfo._tbUseMono ? 0 : cSecondary;
+	COLORREF cNew = 0;
+
+	switch (tbInfo._tbColor)
+	{
+		case FluentColor::accent:
+		{
+			cNew = 0;
+			break;
+		}
+
+		case FluentColor::red:
+		{
+			cNew = RGB(0xE8, 0x11, 0x23);
+			break;
+		}
+
+		case FluentColor::green:
+		{
+			cNew = RGB(0x00, 0x8B, 0x00);
+			break;
+		}
+
+		case FluentColor::blue:
+		{
+			cNew = RGB(0x00, 0x78, 0xD4);
+			break;
+		}
+
+		case FluentColor::purple:
+		{
+			cNew = RGB(0xB1, 0x46, 0xC2);
+			break;
+		}
+
+		case FluentColor::cyan:
+		{
+			cNew = RGB(0x00, 0xB7, 0xC3);
+			break;
+		}
+
+		case FluentColor::olive:
+		{
+			cNew = RGB(0x49, 0x82, 0x05);
+			break;
+		}
+
+		case FluentColor::yellow:
+		{
+			cNew = RGB(0xFF, 0xB9, 0x00);
+			break;
+		}
+
+		case FluentColor::custom:
+		{
+			if (tbInfo._tbCustomColor != 0)
+			{
+				cNew = tbInfo._tbCustomColor;
+				break;
+			}
+			[[fallthrough]];
+		}
+
+		case FluentColor::defaultColor:
+		{
+			if (tbInfo._tbUseMono)
+			{
+				cNew = cMain;
+				break;
+			}
+			[[fallthrough]];
+		}
+
+		default:
+		{
+			return false;
+		}
+	}
+
+	colorMappings = { {cOld, cNew} };
+	return IconList::changeFluentIconColor(phIcon, colorMappings);
+}
+
 void ToolBarIcons::init(ToolBarButtonUnit *buttonUnitArray, int arraySize, const std::vector<DynamicCmdIcoBmp>& moreCmds)
 {
 	for (int i = 0 ; i < arraySize ; ++i)
 		_tbiis.push_back(buttonUnitArray[i]);
-	
+
 	_moreCmds = moreCmds;
 }
 
@@ -134,14 +337,14 @@ void ToolBarIcons::reInit(int size)
 	{
 		if (_tbiis[i]._defaultIcon != -1)
 		{
-			_iconListVector[HLIST_DEFAULT].addIcon(_tbiis[i]._defaultIcon, size, size, _tbiis[i]._stdIcon);
+			_iconListVector[HLIST_DEFAULT].addIcon(_tbiis[i]._defaultIcon, size, size, _tbiis[i]._stdIcon, true);
 			_iconListVector[HLIST_DISABLE].addIcon(_tbiis[i]._grayIcon, size, size, _tbiis[i]._stdIcon);
-			_iconListVector[HLIST_DEFAULT2].addIcon(_tbiis[i]._defaultIcon2, size, size, _tbiis[i]._stdIcon);
+			_iconListVector[HLIST_DEFAULT2].addIcon(_tbiis[i]._defaultIcon2, size, size, _tbiis[i]._stdIcon, true);
 			_iconListVector[HLIST_DISABLE2].addIcon(_tbiis[i]._grayIcon2, size, size, _tbiis[i]._stdIcon);
 
-			_iconListVector[HLIST_DEFAULT_DM].addIcon(_tbiis[i]._defaultDarkModeIcon, size, size, _tbiis[i]._stdIcon);
+			_iconListVector[HLIST_DEFAULT_DM].addIcon(_tbiis[i]._defaultDarkModeIcon, size, size, _tbiis[i]._stdIcon, true);
 			_iconListVector[HLIST_DISABLE_DM].addIcon(_tbiis[i]._grayDarkModeIcon, size, size, _tbiis[i]._stdIcon);
-			_iconListVector[HLIST_DEFAULT_DM2].addIcon(_tbiis[i]._defaultDarkModeIcon2, size, size, _tbiis[i]._stdIcon);
+			_iconListVector[HLIST_DEFAULT_DM2].addIcon(_tbiis[i]._defaultDarkModeIcon2, size, size, _tbiis[i]._stdIcon, true);
 			_iconListVector[HLIST_DISABLE_DM2].addIcon(_tbiis[i]._grayDarkModeIcon2, size, size, _tbiis[i]._stdIcon);
 		}
 	}
