@@ -67,6 +67,22 @@ public :
 	void sortFileSizeDSC();
 	void doRefresh(bool invalidate = false);
 
+public:
+	// for message hook
+	static HHOOK _hMsgHook;
+	static HWND _hThisDlg;
+
+	static LRESULT CALLBACK getMsgProc(int code, WPARAM wParam, LPARAM lParam);
+	void initMessageHook() {
+		_hMsgHook = SetWindowsHookEx(WH_GETMESSAGE, getMsgProc, nullptr, GetCurrentThreadId());
+	}
+	void removeMessageHook() {
+		if (_hMsgHook) {
+			UnhookWindowsHookEx(_hMsgHook);
+			_hMsgHook = nullptr;
+		}
+	}
+
 protected :
 	intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) override;
 	BOOL onInitDialog() override;
