@@ -19,14 +19,14 @@
 
 //************ Notepad++ version **************************
 
-#define NOTEPAD_PLUS_VERSION L"Notepad++ v8.8.1"
+#define NOTEPAD_PLUS_VERSION L"Notepad++ v8.8.2"
 
 // should be X.Y : ie. if VERSION_DIGITALVALUE == 4, 7, 1, 0 , then X = 4, Y = 71
 // ex : #define VERSION_VALUE L"5.63\0"
-#define VERSION_INTERNAL_VALUE L"8.81\0"
+#define VERSION_INTERNAL_VALUE L"8.82\0"
 
-#define VERSION_PRODUCT_VALUE L"8.8.1\0"
-#define VERSION_DIGITALVALUE 8, 8, 1, 0
+#define VERSION_PRODUCT_VALUE L"8.8.2\0"
+#define VERSION_DIGITALVALUE 8, 8, 2, 0
 
 //**********************************************************
 
@@ -45,7 +45,7 @@
 //#define IDI_SAMESEXMARRIAGE      102
 //#define IDI_TAIWANSSOVEREIGNTY     105
 //#define IDI_TAIWANSSOVEREIGNTY_DM  106
-#define IDI_WITHUKRAINE            105
+//#define IDI_WITHUKRAINE            105
 #define IDR_RT_MANIFEST            103
 #define IDI_ICONABSENT             104
 
@@ -267,7 +267,9 @@
 #define IDI_UNSAVED_DM_ICON      510
 #define IDI_MONITORING_DM_ICON   511
 #define IDI_READONLY_DM_ICON     512
-
+#define IDI_READONLYSYS_ICON     513
+#define IDI_READONLYSYS_DM_ICON  514
+#define IDI_READONLYSYS_ALT_ICON 515
 
 #define IDI_PROJECT_WORKSPACE          601
 #define IDI_PROJECT_WORKSPACEDIRTY     602
@@ -664,14 +666,14 @@
 	#define NPPM_INTERNAL_UPDATETITLEBAR                (NOTEPADPLUS_USER_INTERNAL + 23)
 	#define NPPM_INTERNAL_CANCEL_FIND_IN_FILES          (NOTEPADPLUS_USER_INTERNAL + 24)
 	#define NPPM_INTERNAL_RELOADNATIVELANG              (NOTEPADPLUS_USER_INTERNAL + 25)
-	#define NPPM_INTERNAL_PLUGINSHORTCUTMOTIFIED        (NOTEPADPLUS_USER_INTERNAL + 26)
+	#define NPPM_INTERNAL_PLUGINSHORTCUTMODIFIED        (NOTEPADPLUS_USER_INTERNAL + 26)
 	#define NPPM_INTERNAL_SCINTILLAFINDERCLEARALL       (NOTEPADPLUS_USER_INTERNAL + 27)
 	#define NPPM_INTERNAL_CHANGETABBARICONSET           (NOTEPADPLUS_USER_INTERNAL + 28)
 	#define NPPM_INTERNAL_SET_TAB_SETTINGS              (NOTEPADPLUS_USER_INTERNAL + 29)
 	#define NPPM_INTERNAL_SETTOOLICONSSET               (NOTEPADPLUS_USER_INTERNAL + 30)
 	#define NPPM_INTERNAL_RELOADSTYLERS                 (NOTEPADPLUS_USER_INTERNAL + 31)
 	#define NPPM_INTERNAL_DOCORDERCHANGED               (NOTEPADPLUS_USER_INTERNAL + 32)
-	#define NPPM_INTERNAL_SETMULTISELCTION              (NOTEPADPLUS_USER_INTERNAL + 33)
+	#define NPPM_INTERNAL_SETMULTISELECTION             (NOTEPADPLUS_USER_INTERNAL + 33)
 	#define NPPM_INTERNAL_SCINTILLAFINDEROPENALL        (NOTEPADPLUS_USER_INTERNAL + 34)
 	#define NPPM_INTERNAL_RECENTFILELIST_UPDATE         (NOTEPADPLUS_USER_INTERNAL + 35)
 	#define NPPM_INTERNAL_RECENTFILELIST_SWITCH         (NOTEPADPLUS_USER_INTERNAL + 36)
@@ -723,7 +725,7 @@
 	#define NPPM_INTERNAL_REFRESHTABBAR                 (NOTEPADPLUS_USER_INTERNAL + 82)
 	#define NPPM_INTERNAL_REDUCETABBAR                  (NOTEPADPLUS_USER_INTERNAL + 83)
 	#define NPPM_INTERNAL_CHANGESELECTTEXTFORGROUND     (NOTEPADPLUS_USER_INTERNAL + 84)
-	#define NPPM_INTERNAL_DRAWINACIVETAB                (NOTEPADPLUS_USER_INTERNAL + 85)
+	#define NPPM_INTERNAL_DRAWINACTIVETAB               (NOTEPADPLUS_USER_INTERNAL + 85)
 	#define NPPM_INTERNAL_DRAWTABTOPBAR                 (NOTEPADPLUS_USER_INTERNAL + 86)
 	//#define NPPM_INTERNAL_TABDBCLK2CLOSE                (NOTEPADPLUS_USER_INTERNAL + 87)
 	#define NPPM_INTERNAL_VERTICALTABBAR                (NOTEPADPLUS_USER_INTERNAL + 88)
@@ -748,6 +750,7 @@
 	#define NPPM_INTERNAL_HIDEMENURIGHTSHORTCUTS        (NOTEPADPLUS_USER_INTERNAL + 107)
 	#define NPPM_INTERNAL_CHANGETOOLBARCOLORABLESTATE   (NOTEPADPLUS_USER_INTERNAL + 108)
 	#define NPPM_INTERNAL_SQLBACKSLASHESCAPE            (NOTEPADPLUS_USER_INTERNAL + 109)
+	#define NPPM_INTERNAL_TOOLBARICONSCHANGED           (NOTEPADPLUS_USER_INTERNAL + 110)
 
 // See Notepad_plus_msgs.h
 //#define NPPMSG   (WM_USER + 1000)
